@@ -38,8 +38,6 @@ tiddler.tags = ['foobar', 'foo bar']
 tiddler.text = "Hello, I'm the content."
 tiddler.modified = '200803030303'
 
-def setup_module(module):
-    pass
 
 def test_generated_txt_string():
     serializer = Serializer('text')
@@ -47,8 +45,8 @@ def test_generated_txt_string():
     string = serializer.to_string()
 
     assert string == expected_string
-    assert '%s' % serializer == expected_string, \
-            'serializer goes to string as expected_string'
+    assert '%s' % serializer == expected_string
+
 
 def test_bad_string_raises():
     serializer = Serializer('text')
@@ -57,6 +55,7 @@ def test_bad_string_raises():
 
     pytest.raises(TiddlerFormatError, 'serializer.from_string(bad_string)')
 
+
 def test_generated_json_string():
     serializer = Serializer('json', environ={'tiddlyweb.config': config})
     serializer.object = tiddler
@@ -71,6 +70,7 @@ def test_generated_json_string():
             config['server_host']['host'],
             config['server_host']['port'])
 
+
 def test_tiddler_from_json():
     serializer = Serializer('json')
     tiddler = Tiddler('test tiddler')
@@ -80,6 +80,7 @@ def test_tiddler_from_json():
     assert tiddler.title == 'test tiddler'
     assert tiddler.text == "Hello, I'm the content."
 
+
 def test_tiddler_html_encode():
     serializer = Serializer('html')
     tiddler = Tiddler('jeremy found a bug')
@@ -90,8 +91,10 @@ def test_tiddler_html_encode():
 
     assert '"Hello." I\'m &gt; than 5 &amp; &lt; you.' in string
 
+
 def test_html_attribute_escape():
-    tiddler = Tiddler('escape "double" quotes & &amp; in <tiddler> field values')
+    tiddler = Tiddler(
+            'escape "double" quotes & &amp; in <tiddler> field values')
     tiddler.bag = u'foo "bar" baz'
     tiddler.modifier = 'Chris "sensei" Dent'
     tiddler.tags = ["foo", 'xxx "yyy" zzz']
@@ -106,18 +109,20 @@ def test_html_attribute_escape():
     assert r'''tags="foo [[xxx &quot;yyy&quot; zzz]]"''' in string
     assert r'''custom="lorem 'ipsum' dolor &quot;sit&quot; amet"''' in string
 
+
 def test_tiddler_json_base64():
     serializer = Serializer('json', environ={'tiddlyweb.config': config})
     tiddler = Tiddler('binarytiddler')
     tiddler.bag = u'foo'
-    tiddler.text = file('test/peermore.png', 'rb').read()
+    with open('test/peermore.png', 'rb') as image_file:
+        tiddler.text = image_file.read()
     bininfo = tiddler.text
-    b64expected = b64encode(tiddler.text)
+    b64expected = b64encode(bininfo)
     tiddler.type = 'image/png'
     serializer.object = tiddler
     string = serializer.to_string()
     info = simplejson.loads(string)
-    assert info['text'] == b64expected
+    assert info['text'] == b64expected.decode('utf-8')
 
     tiddler = serializer.from_string(string)
     assert tiddler.text == bininfo
@@ -126,6 +131,7 @@ def test_tiddler_json_base64():
     string = simplejson.dumps(info)
     pytest.raises(TiddlerFormatError, 'serializer.from_string(string)')
 
+
 def test_tiddler_json_render():
     serializer = Serializer('json', environ={'tiddlyweb.query': {
         'render': [1]}, 'tiddlyweb.config': config})
@@ -140,6 +146,7 @@ def test_tiddler_json_render():
     assert info['render'] == '<pre>\n!Hi\n//you//</pre>\n'
     assert info['text'] == '!Hi\n//you//'
 
+
 def test_tiddler_json_render_skinny():
     serializer = Serializer('json', environ={'tiddlyweb.query': {
         'render': ['1'], 'fat': ['0']}, 'tiddlyweb.config': config})
@@ -154,6 +161,7 @@ def test_tiddler_json_render_skinny():
     assert info['render'] == '<pre>\n!Hi\n//you//</pre>\n'
     pytest.raises(KeyError, "info['text']")
 
+
 def test_tiddler_no_text():
     serializer = Serializer('text')
     tiddler = Tiddler('hello')
