@@ -8,16 +8,21 @@ import py.test
 
 from tiddlyweb.serializer import Serializer
 
+
 def setup_module(module):
     pass
 
+
 def test_module_load_fail():
-    py.test.raises(ImportError, 'serializer = Serializer("notexistserialization")')
+    py.test.raises(ImportError,
+            'serializer = Serializer("notexistserialization")')
+
 
 def test_load_module_on_other_path():
     serializer = Serializer("test.other.tiddlyweb.serializations.debug")
     assert type(serializer) == Serializer
 
+
 def test_wrong_class():
     class Foo(object):
         pass
@@ -29,6 +34,3 @@ def test_wrong_class():
 
     py.test.raises(AttributeError, 'serializer.to_string()')
     py.test.raises(AttributeError, 'serializer.from_string(string)')
-
-
-
