@@ -4,16 +4,17 @@ Tests for a [text[<string>]] style filter.
 
 
 from tiddlyweb import control
-from tiddlyweb.model.tiddler import Tiddler
 from tiddlyweb.model.bag import Bag
 
-from fixtures import muchdata, reset_textstore, _teststore
+from .fixtures import muchdata, reset_textstore, _teststore
+
 
 def setup_module(module):
     reset_textstore()
     module.store = _teststore()
     muchdata(module.store)
 
+
 def test_filter_by_text():
     bag = Bag('bag0')
     bag = store.get(bag)
@@ -27,6 +28,7 @@ def test_filter_by_text():
     assert len(found_tiddlers) == 1
     assert found_tiddlers[0].title == 'tiddler0'
 
+
 def test_filter_by_text_string():
     bag = Bag('bag0')
     bag = store.get(bag)
@@ -40,6 +42,7 @@ def test_filter_by_text_string():
     assert len(found_tiddlers) == 1
     assert found_tiddlers[0].title == 'tiddler0'
 
+
 def test_filter_by_text_string_negate():
     bag = Bag('bag0')
     bag = store.get(bag)
