@@ -3,20 +3,20 @@ Test using / in names and titles.
 """
 
 
-import os
-
-from fixtures import reset_textstore, _teststore
-
 from tiddlyweb.model.bag import Bag
 from tiddlyweb.model.tiddler import Tiddler
 
+from .fixtures import reset_textstore, _teststore
+
+
 def setup_module(module):
     reset_textstore()
-    module.store = _teststore()
-    module.bag = Bag('bag/puss')
-    module.store.put(module.bag)
+
 
 def test_tiddler_title_with_slash():
+    store = _teststore()
+    bag = Bag('bag/puss')
+    store.put(bag)
     tiddler = Tiddler('hello/monkey')
     tiddler.bag = u'bag/puss'
     tiddler.text = 'artifice'
@@ -32,5 +32,3 @@ def test_tiddler_title_with_slash():
 
     assert tiddler2.title == 'hello/monkey'
     assert tiddler2.text == 'artifice'
-
-
