@@ -12,6 +12,8 @@ from tiddlyweb.serializer import Serializer, NoSerializationError
 from tiddlyweb.util import sha
 from tiddlyweb.web.util import get_serialize_type, check_incoming_etag
 
+from tiddlyweb.fixups import basestring
+
 
 def list_entities(environ, start_response, method_name,
         store_list=None, serializer_list=None):
@@ -33,7 +35,7 @@ def list_entities(environ, start_response, method_name,
 
     try:
         kept_entities = _filter_readable(environ, store_list(), filters)
-    except FilterError, exc:
+    except FilterError as exc:
         raise HTTP400(exc)
 
     etag_string = '"%s:%s"' % (kept_entities.hexdigest(),
@@ -84,6 +86,6 @@ def _filter_readable(environ, entities, filters):
                 kept_entities.add(entity)
             except(UserRequiredError, ForbiddenError):
                 pass
-    except AttributeError, exc:
+    except AttributeError as exc:
         raise FilterError('malformed filter: %s' % exc)
     return kept_entities
